from setuptools import setup

setup(name='Gaussian_and_Binomial247',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['Gaussian_and_Binomial247'],
      zip_safe=False)
